@@ -22,10 +22,10 @@ public:
   void bodyBegin(const pdbLoc& loc);
   void bodyEnd  (const pdbLoc& loc);
 
-  const pdbLoc& headBegin(void) const;
-  const pdbLoc& headEnd  (void) const;
-  const pdbLoc& bodyBegin(void) const;
-  const pdbLoc& bodyEnd  (void) const;
+  const pdbLoc& headBegin() const;
+  const pdbLoc& headEnd  () const;
+  const pdbLoc& bodyBegin() const;
+  const pdbLoc& bodyEnd  () const;
 
   virtual void adjustPtrs(PDB*);
 
