@@ -40,125 +40,17 @@ void pdb_ERROR(const char *msg, const char *item, int val) {
 }
 
 #include "pdbTraits.h"
-
-template<class tag>
-typename PDBTraits<tag>::item_t *PDB::findItem(tag, int id) {
-  typedef typename PDBTraits<tag>::item_t item_t;
-
-  typename PDBTraits<tag>::map_t& map = PDBTraits<tag>::getMap(this);
-  typename PDBTraits<tag>::map_t::iterator it = map.find(id);
-  if ( it != map.end() )
-    return (*it).second;
-  else {
-    item_t* item = new item_t(id);
-    map[id] = item;
-    PDBTraits<tag>::getItems(this).push_back(item);
-    return item;
-  }
-}
-
-template<class tag>
-typename PDBTraits<tag>::item_t* PDB::findItem(tag, const string& name, int id) {
-  typedef typename PDBTraits<tag>::item_t item_t;
-
-  typename PDBTraits<tag>::map_t& map = PDBTraits<tag>::getMap(this);
-  typename PDBTraits<tag>::map_t::iterator it = map.find(id);
-  if ( it != map.end() ) {
-    item_t *i = (*it).second;
-    if ( i->name()[0] ) pdb_ERROR("Duplicate", i->desc(), id);
-    i->name(name);
-    return i;
-  } else {
-    item_t* item = new item_t(name, id);
-    map[id] = item;
-    PDBTraits<tag>::getItems(this).push_back(item);
-    return item;
-  }
-}
-
-template<class tag>
-void PDB::finalCheck(tag) {
-  typename PDBTraits<tag>::map_t& map = PDBTraits<tag>::getMap(this);
-  typename PDBTraits<tag>::vec_t& vec = PDBTraits<tag>::getVec(this);
-  for (typename PDBTraits<tag>::map_t::const_iterator mit = map.begin();
-       mit != map.end(); ++mit) {
-    if (! (*mit).second->name()[0] )
-      pdb_ERROR("Undefined", (*mit).second->desc(), (*mit).second->id());
-    (*mit).second->process(this);
-    vec.push_back((*mit).second);
-  }
-}
-
-template<class tag>
-void PDB::markDuplicates(tag, PDB& other) {
-  typename PDBTraits<tag>::vec_t& vecOld = PDBTraits<tag>::getVec(this);
-  typename PDBTraits<tag>::vec_t& vecNew = PDBTraits<tag>::getVec(&other);
-  typename PDBTraits<tag>::map_t& mapOld = PDBTraits<tag>::getMap(this);
-  typename PDBTraits<tag>::map_t& mapNew = PDBTraits<tag>::getMap(&other);
-  int maxId = 0;
-  bool oldDupls = false;
-
-  // look for duplicate item in "other" PDB
-  // use "findDuplicate" to check for duplicates
-  for (typename PDBTraits<tag>::vec_t::const_iterator oit = vecOld.begin();
-       oit != vecOld.end(); ++oit) {
-    for (typename PDBTraits<tag>::vec_t::const_iterator nit = vecNew.begin();
-         nit != vecNew.end(); ++nit) {
-      // only compare Items if not marked as duplicate yet
-      if ( (*nit)->newId() == pdbSimpleItem::UNIQUE ) {
-        pdbSimpleItem::dupl_t res = (*oit)->findDuplicate(*nit);
-        if ( res == pdbSimpleItem::OLDDUPL ) {
-          // duplicate in "old" PDB 
-          (*oit)->newId((*nit)->id());  // "old" id, needs to be fixed later
-          oldDupls = true;
-          break;
-        } else if ( res == pdbSimpleItem::NEWDUPL ) {
-          // duplicate in "other" PDB
-          (*nit)->newId((*oit)->id());
-          break;
-        }
-      }
-    }
-    // determine highest used ID
-    if ( (*oit)->id() > maxId ) maxId = (*oit)->id();
-  }
-
-  // assign new items (non duplicates) from "other" PDB new ID
-  // and insert them in "old" PDB (map AND vecs!)
-  for (typename PDBTraits<tag>::vec_t::const_iterator nit = vecNew.begin();
-       nit != vecNew.end(); ++nit) {
-    if ( (*nit)->newId() == pdbSimpleItem::UNIQUE ) {
-      ++maxId;
-      mapOld[maxId] = (*nit);
-      vecOld.push_back(*nit);
-      PDBTraits<tag>::getItems(this).push_back(*nit);
-      (*nit)->id(maxId);
-
-      // mark them, so they are not deleted if "other" PDB is destructed
-      (*nit)->newId(pdbSimpleItem::NOTDEL);
-    }
-  }
-
-  // if duplicates in "old" PDB, fix the references to the new id's
-  if ( oldDupls ) {
-    for (typename PDBTraits<tag>::vec_t::const_iterator oit = vecOld.begin();
-         oit != vecOld.end(); ++oit) {
-      if ( (*oit)->newId() > pdbSimpleItem::UNIQUE ) {
-         (*oit)->newId((mapNew[(*oit)->newId()])->id());
-      }
-    }
-  }
-}
+#include "pdbTdefs.h"
 
 static bool isDuplVec(const pdbSimpleItem* s) {
   return s->newId() > pdbSimpleItem::UNIQUE;
 }
 
-static bool isRoDuplMap(map<int, pdbCRoutine*>::value_type& r) {
+static bool isRoDuplMap(std::map<int, pdbCRoutine*>::value_type& r) {
   return (r.second)->newId() > pdbSimpleItem::UNIQUE;
 }
 
-static bool isClDuplMap(map<int, pdbClass*>::value_type& r) {
+static bool isClDuplMap(std::map<int, pdbClass*>::value_type& r) {
   return (r.second)->newId() > pdbSimpleItem::UNIQUE;
 }
 
@@ -433,13 +325,15 @@ bool PDB::read(char *filename) {
       string name( (*value == '\0' || *(value+1) == '\0') ? "$NA$" : ++value);
 
       // check for very long lines
-      while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+      while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE) {
         inbuf[INBUF_SIZE-1] = '\n';
         if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);     
         istr.getline(inbuf, INBUF_SIZE);
         name += inbuf;
       }
 
+
+
       if ( fst=='r' && snd=='o' ) {
         if ( language() & LA_C_or_CXX ) {
           iptr = fiptr = tiptr = rptr = crptr =
@@ -659,7 +553,7 @@ bool PDB::read(char *filename) {
           string name(value);
 
           // check for very long lines
-          while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+          while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE) {
             inbuf[INBUF_SIZE-1] = '\n';
             if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);     
             istr.getline(inbuf, INBUF_SIZE);
@@ -731,7 +625,7 @@ bool PDB::read(char *filename) {
                 cmt->cmtEnd(pdbLoc(f, l, c));
 	      }
 	      string txt(ptr+1);
-	      while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+	      while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE ) {
                 inbuf[INBUF_SIZE-1] = '\n';
                 if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);
                 istr.getline(inbuf, INBUF_SIZE);
@@ -759,7 +653,7 @@ bool PDB::read(char *filename) {
         case MTEXT:    // ---- Macro Text
           if (mptr) {
             string txt(value);
-            while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+            while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE ) {
               inbuf[INBUF_SIZE-1] = '\n';
               if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);     
               istr.getline(inbuf, INBUF_SIZE);
@@ -785,7 +679,7 @@ bool PDB::read(char *filename) {
         case PTEXT:    // ---- Pragma Text
           if (pptr) {
             string txt(value);
-            while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+            while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE ) {
               inbuf[INBUF_SIZE-1] = '\n';
               if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);     
               istr.getline(inbuf, INBUF_SIZE);
@@ -959,7 +853,7 @@ bool PDB::read(char *filename) {
         case TTEXT:    // ---- Template Text
           if (tptr) {
             string txt(value);
-            while ( inbuf[INBUF_SIZE-1] != '\n' ) {
+            while ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE) {
               inbuf[INBUF_SIZE-1] = '\n';
               if (istr.fail()) istr.clear(istr.rdstate() & ~ios::failbit);     
               istr.getline(inbuf, INBUF_SIZE);
@@ -1232,7 +1126,7 @@ bool PDB::read(char *filename) {
         }
       }
     }
-    if ( inbuf[INBUF_SIZE-1] != '\n' ) {
+    if ( inbuf[INBUF_SIZE-1] != '\n' && istr.gcount() != INBUF_SIZE) {
       pdb_ERROR("*** LINE TOO LONG ***", "");
       cerr << inbuf << endl;
       exit(1);
