@@ -20,10 +20,17 @@
 # include <string>
   using std::getline;
 #endif
-#include <unistd.h>
+
+extern void pdb_ERROR(const char *msg, const char *item, int val);
+#ifdef _MSC_VER
+ #include "getopt.h"
+#else
+ #include <unistd.h>
+#endif
 #include <ctype.h>
 #include "pdbAll.h"
 #include "pdbTraits.h"
+#include "pdbTdefs.h"
 
 //---------------------------------------------------------------------------
 namespace {
@@ -147,7 +154,7 @@ namespace {
    *              IN:          file:  file pointer
    *              IN:           pdb:  program database
    */
-  void process_preStmt(vector<string>& preStmt, int lineno,
+  bool process_preStmt(vector<string>& preStmt, int lineno,
                        string::size_type ppos, pdbFile* file, PDB& pdb) {
     unsigned s = preStmt.size();
     bool inComment = false;
@@ -248,6 +255,7 @@ namespace {
         pr->text(ptext);
       }
     }
+    return inComment;
   }
 
   /*
@@ -386,8 +394,8 @@ namespace {
         preStmt.push_back(line);
         if ( line[line.size()-1] != '\\' ) {
           preContLine = false;
-          process_preStmt(preStmt, lineno-preStmt.size()+1, lstart+1,
-                          file, pdb);
+          inComment = process_preStmt(preStmt, lineno-preStmt.size()+1,
+	                              lstart+1, file, pdb);
           preStmt.clear();
         }
 
@@ -401,7 +409,7 @@ namespace {
         if ( line[line.size()-1] == '\\' ) {
           preContLine = true;
         } else {
-          process_preStmt(preStmt, lineno, lstart+1, file, pdb);
+          inComment = process_preStmt(preStmt, lineno, lstart+1, file, pdb);
           preStmt.clear();
         }
   
