@@ -10,7 +10,11 @@
 # include <fstream>
   using std::ofstream;
 #endif
-#include <unistd.h>
+#ifdef _MSC_VER
+ #include "getopt.h"
+#else
+ #include <unistd.h>
+#endif
 #include <stdlib.h>
 #include "pdbAll.h"
 
