@@ -747,6 +747,8 @@ struct run_control * readpdbhtmlrc() {
 
    struct run_control * rc = new run_control();
 
+   rc->find_doc_files_in = 0;
+   rc->write_html_files_to = 0;
    rc->add_line_numbers = false;
    rc->just_build_pdbhtmlrc_html = false;
    rc->add_backtoindex_footer = true;
