@@ -4,7 +4,11 @@
 /* Forschungszentrum Juelich, Zentralinstitut fuer Angewandte Mathematik */
 /*************************************************************************/
 
-#include <unistd.h>
+#ifdef _MSC_VER
+ #include "getopt.h"
+#else
+ #include <unistd.h>
+#endif
 #include "pdb.h"
 
 int main(int argc, char *argv[]) {
