@@ -10,7 +10,11 @@
 # include <iomanip>
   using std::setw;
 #endif
-#include <unistd.h>
+#ifdef _MSC_VER
+ #include "getopt.h"
+#else
+ #include <unistd.h>
+#endif
 #include "pdb.h"
 #include "pdbRoutine.h"
 #include "pdbClass.h"
