@@ -28,7 +28,11 @@
  *
  * Conforms to DTD specified in mapping.dtd included with this code.
  */
-#include <unistd.h>
+#ifdef _MSC_VER
+ #include "getopt.h"
+#else
+ #include <unistd.h>
+#endif
 #include "pdb.h"
 #include "pdbAll.h"
 #include <vector>
