@@ -31,7 +31,14 @@
 
 #else
 #ifdef __APPLE__
+#define va_start(v,l)
+#define __builtin_va_start(v,l)
+#define __builtin_va_end(a)
+#define va_end(v)
+#define va_copy(d,s)
+
 #include "/usr/include/stdarg.h"
+#define va_arg(v,l) (l)0
 #else /* __APPLE__ */
 #include <../stdarg.h>
 #endif /* __APPLE__ */
